## What

Brief description of the change.

## Why

What problem does this solve?

## How

Key implementation details.

## Testing

- [ ] Tests added/updated
- [ ] `pytest` passes
- [ ] `ruff check .` passes
